@@ -4,6 +4,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -14,8 +15,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -23,8 +24,8 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
@@ -292,9 +293,7 @@ BVerifyMove(char *s, unsigned short *mv, int moveno)
             UnmakeMove(opponent, &xnode, &tempb, &tempc, &tempsf, &tempst);
             /* Illegal move in check */
 #if !defined QUIETBOOKGEN
-            /* 077: "Illegal move (in check) %s" */
-            printf(CP[77]);
-            printf("\n");
+            puts("Illegal move (in check) %s");
             bkdisplay(s, cnt, moveno);
 #endif
             return false;
@@ -314,8 +313,7 @@ BVerifyMove(char *s, unsigned short *mv, int moveno)
 
     /* Illegal move */
 #if !defined QUIETBOOKGEN
-    /* 075: "Illegal move (no match)%s\n" */
-    printf(CP[75], s);
+    printf("Illegal move (no match) %s\n", s);
     bkdisplay(s, cnt, moveno);
 #endif
     return false;
@@ -878,8 +876,7 @@ GetOpenings(void)
 
         }
 
-        /* 213: "Book used %d(%d)." */
-        sprintf(msg, CP[213], B.bookcount, B.booksize);
+        sprintf(msg, "Book used %d(%d).", B.bookcount, B.booksize);
         ShowMessage(msg);
     }
 
@@ -890,8 +887,7 @@ GetOpenings(void)
     /* Now get ready to play .*/
     if (!B.bookcount)
     {
-        /* 212: "Can't find book." */
-        ShowMessage(CP[212]);
+        ShowMessage("Can't find book.");
         Book = 0;
     }
 }
