@@ -6,6 +6,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -16,8 +17,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -25,8 +26,8 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
@@ -34,6 +35,8 @@
 #ifndef _CURSESDSP_H_
 #define _CURSESDSP_H_
 
+#include "gnushogi.h"
+
 /* The following are common to rawdsp.h and cursesdsp.h */
 
 void Curses_ChangeAlphaWindow(void);
@@ -49,7 +52,9 @@ void Curses_EditBoard(void);
 void Curses_ExitShogi(void);
 void Curses_GiveHint(void);
 void Curses_Initialize(void);
+void Curses_ShowNodeCnt(long NodeCnt);
 void Curses_OutputMove(void);
+void Curses_PollForInput(void);
 void Curses_SearchStartStuff(short side);
 void Curses_SelectLevel(char *sx);
 void Curses_SetContempt(void);
@@ -58,30 +63,22 @@ void Curses_ShowDepth(char ch);
 void Curses_ShowGameType(void);
 void Curses_ShowLine(unsigned short *bstline);
 void Curses_ShowMessage(char *s);
+void Curses_AlwaysShowMessage(const char *format, va_list ap);
+void Curses_Printf(const char *format, va_list ap);
+void Curses_doRequestInputString(const char* fmt, char* buffer);
+int  Curses_GetString(char* sx);
+void Curses_SetupBoard(void);
 void Curses_ShowPatternCount(short side, short n);
 void Curses_ShowPostnValue(short sq);
 void Curses_ShowPostnValues(void);
+void Curses_ShowPrompt(void);
 void Curses_ShowResponseTime(void);
 void Curses_ShowResults(short score, unsigned short *bstline, char ch);
 void Curses_ShowSidetoMove(void);
 void Curses_ShowStage(void);
 void Curses_TerminateSearch(int sig);
+void Curses_UpdateClocks(void);
 void Curses_UpdateDisplay(short f, short t, short redraw, short isspec);
 void Curses_help(void);
 
-
-/* The following are only found in cursesdsp.h: */
-
-void ClearEoln(void);
-void ClearMessage(void);
-void DrawPiece(short sq);
-void ShowHeader(void);
-void ShowNodeCnt(long NodeCnt);
-void ShowPlayers(void);
-void ShowPrompt(void);
-void ShowScore(short score);
-void UpdateClocks(void);
-void gotoXY(short x, short y);
-
 #endif /* _CURSESDSP_H_ */
-
