@@ -4,6 +4,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -14,8 +15,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -23,8 +24,8 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
@@ -116,12 +117,28 @@ const short kingP[3] =
 { 4, 76, 0 };
 
 const small_short relative_value[NO_PIECES] =
-{ 0,  1,  3,  4,  7,  9,  10,  12,
-  2,  5,  6,  8, 11, 13,  14 };
+{ 0,  1,
+#ifndef MINISHOGI
+  3,  4,
+#endif
+  7,  9,  10,  12,
+  2,
+#ifndef MINISHOGI
+  5,  6,
+#endif
+8, 11, 13,  14 };
 
 const long control[NO_PIECES] =
-{ 0,  ctlP,  ctlL,  ctlN,  ctlS,  ctlG, ctlB, ctlR,
-     ctlPp, ctlLp, ctlNp, ctlSp, ctlBp, ctlRp, ctlK };
+{ 0,  ctlP,
+#ifndef MINISHOGI
+  ctlL,  ctlN,
+#endif
+  ctlS,  ctlG, ctlB, ctlR,
+  ctlPp,
+#ifndef MINISHOGI
+  ctlLp, ctlNp,
+#endif
+  ctlSp, ctlBp, ctlRp, ctlK };
 
 short stage, stage2;
 short balance[2];
@@ -179,3 +196,8 @@ short use_ttable = true;
 unsigned int ttblsize = ttblsz;
 struct hashentry  *ttable[2] = { NULL, NULL };
 #endif
+
+char *DRAW;
+char *DRAW_REPETITION = "Repetition";
+char *DRAW_MAXMOVES = "Max Moves";
+char *DRAW_JUSTDRAW = "Drawn game!";
