@@ -4,6 +4,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -14,8 +15,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -23,8 +24,8 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
@@ -36,7 +37,15 @@
 #define MAX_OPENING_SEQUENCE 20
 #define MAX_PATTERN          200
 
-char *patternfile = PATTERNFILE;
+static char *patternfile = PATTERNFILE;
+small_short pattern_data[MAX_PATTERN_DATA];
+
+/* minimal ShowMessage to avoid dependency on extraneous display code */
+void
+ShowMessage(char *s)
+{
+    printf("%s\n", s);
+}
 
 #define is_digit(c) (((c) >= '0') && ((c) <= '9'))
 #define is_alpha(c) ((((c) >= 'a') && ((c) <= 'z')) \
@@ -180,7 +189,6 @@ ScanPattern (char *s, short *pindex)
 
 void
 ReadOpeningSequences (short *pindex)
-
 {
     FILE *fd;
     char s[256];
@@ -226,17 +234,13 @@ ReadOpeningSequences (short *pindex)
         pattern_data[(*pindex)++] = END_OF_PATTERNS;
         pattern_data[(*pindex)++] = END_OF_SEQUENCES;
 
-        if (NOT_CURSES)
-        {
-            sprintf(s,
-                    "Pattern: %d bytes for %d sequences with %d patterns.\n",
-                    *pindex, max_opening_sequence, max_pattern);
-            ShowMessage(s);
-        }
+        sprintf(s,
+                "Pattern: %d bytes for %d sequences with %d patterns.\n",
+                *pindex, max_opening_sequence, max_pattern);
+        ShowMessage(s);
+
         fclose(fd);
-    }
-    else if (NOT_CURSES)
-    {
+    } else {
         sprintf(s, "no pattern file '%s'", patternfile);
         ShowMessage(s);
     }
