@@ -6,6 +6,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -16,8 +17,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -25,13 +26,12 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
 
-#include "version.h"
 #include "gnushogi.h"
 #include "pattern.h"
 
@@ -39,73 +39,19 @@
 extern void ReadOpeningSequences(short *pindex);
 extern void WriteOpeningSequences(short pindex);
 
-/*
-
-small_short PieceCnt[2];
-small_short PieceList[2][NO_SQUARES];
-small_short PieceIndex[NO_SQUARES];
-
 small_short board[NO_SQUARES];
 small_short color[NO_SQUARES];
 
-*/
-
-void
-test_distance()
-{
-    short side, piece, f, t, d;
-
-    for (side = 0; side <= 1; side++)
-    {
-        printf("SIDE = %d\n", side);
-
-        for (piece = pawn; piece <= king; piece++)
-        {
-            printf("PIECE = %d\n", piece);
-
-            for (f = 0; f < NO_SQUARES; f++)
-            {
-                printf("FROM %d TO ", f);
-
-                for (t = 0; t < NO_SQUARES; t++)
-                {
-                    d = piece_distance(side, piece, f, t);
-
-                    if (d != CANNOT_REACH)
-                        printf("%d:%d ", t, d);
-                }
-
-                printf("\n");
-            }
-        }
-    }
-
-}
-
-
-
 int
 main(int argc, char **argv)
-
 {
-
     short sq, side, max_pattern_data;
 
-#if defined(EXTLANGFILE)
-    char *Lang = NULL;
-#endif
-
 #ifdef TEST_DISTANCE
     short d;
     char  s[80];
 #endif
 
-    display_type = DISPLAY_RAW;
-
-#if defined(EXTLANGFILE)
-    InitConst(Lang);
-#endif
-
     Initialize_data();
 
     for (sq = 0; sq < NO_SQUARES; sq++)
@@ -143,4 +89,3 @@ main(int argc, char **argv)
 
     return 0;
 }
-
